//LabPlot : GraphListDialog.h

#ifndef GRAPHLISTDIALOG_H
#define GRAPHLISTDIALOG_H

#include "ListDialog.h"

class GraphListDialog : public ListDialog
{
	Q_OBJECT
public:
	GraphListDialog(class MainWin *mw, const char *name=0);
public slots:
	void newData();
	void newFunction();
	
	int apply_clicked() { return 0; }	// virtual
private:
	Plot *plot;		// active plot
};

#endif // GRAPHLISTDIALOG_H
